@@ -18,8 +18,8 @@
 #include "config.h"
 
 #include <errno.h>
-#include <limits.h>
 #include <math.h>
+
 #include <new>
 
 #include <QApplication>
@@ -208,7 +208,7 @@ int Kwave::SignalManager::loadFile(const QUrl &url)
 	if (use_src_size) resulting_size = src.size();
 
 	// prepare and show the progress dialog
-	dialog = new Kwave::FileProgress(m_parent_widget,
+	dialog = new(std::nothrow) Kwave::FileProgress(m_parent_widget,
 	    QUrl(filename), resulting_size,
 	    info.length(), info.rate(), info.bits(), info.tracks());
 	Q_ASSERT(dialog);
@@ -410,11 +410,13 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 	}
 
 	// prepare and show the progress dialog
-	Kwave::FileProgress *dialog = new Kwave::FileProgress(m_parent_widget,
-	    QUrl(filename), file_info.length() * file_info.tracks() *
-	    (file_info.bits() >> 3),
-	    file_info.length(), file_info.rate(), file_info.bits(),
-	    file_info.tracks());
+	Kwave::FileProgress *dialog = new(std::nothrow)
+	    Kwave::FileProgress(m_parent_widget, QUrl(filename),
+	        file_info.length() * file_info.tracks() *
+	        (file_info.bits() >> 3),
+	        file_info.length(), file_info.rate(), file_info.bits(),
+	        file_info.tracks()
+	    );
 	Q_ASSERT(dialog);
 	QObject::connect(&src,   SIGNAL(progress(qreal)),
 	                 dialog, SLOT(setValue(qreal)),
@@ -433,9 +435,6 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 	    // we have to adjust all position aware meta data
 	    meta.cropByRange(ofs, ofs + len - 1);
 
-	    // filter out all the track bound meta data that is not selected
-	    meta.cropByTracks(selectedTracks());
-
 	    // set the filename in the copy of the fileinfo, the original
 	    // file which is currently open keeps it's name
 	    Kwave::FileInfo info(meta);
@@ -926,19 +925,6 @@ void Kwave::SignalManager::insertTrack(unsigned int index)
 	// do an "append"
         m_signal.appendTrack(len, Q_NULLPTR);
     } else {
-	if (m_undo_enabled) {
-	    // undo action for the corresponding meta data change
-	    QList<unsigned int> tracks;
-	    for (unsigned int t = index; t < count; t++) tracks.append(t);
-	    Kwave::MetaDataList list = m_meta_data.selectByTracks(tracks);
-	    if (!list.isEmpty() && !registerUndoAction(
-		new(std::nothrow) Kwave::UndoModifyMetaDataAction(list)))
-		    return;
-	}
-
-	// adjust the track bound meta data
-	m_meta_data.insertTrack(index);
-
 	// insert into the list
         m_signal.insertTrack(index, len, Q_NULLPTR);
     }
@@ -961,19 +947,8 @@ void Kwave::SignalManager::deleteTrack(unsigned int index)
 	if (!registerUndoAction(new(std::nothrow)
 	    UndoDeleteTrack(m_signal, index)))
 		return;
-
-	// undo action for the corresponding meta data change
-	QList<unsigned int> tracks;
-	for (unsigned int t = index; t < count; t++) tracks.append(t);
-	Kwave::MetaDataList list = m_meta_data.selectByTracks(tracks);
-	if (!list.isEmpty() && !registerUndoAction(
-	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(list)))
-		return;
     }
 
-    // adjust the track bound meta data
-    m_meta_data.deleteTrack(index);
-
     setModified(true);
     m_signal.deleteTrack(index);
 }
@@ -1017,8 +992,8 @@ void Kwave::SignalManager::slotSamplesInserted(unsigned int track,
 
     // only adjust the meta data once per operation
     QList<unsigned int> tracks = selectedTracks();
-    if (track == tracks[0]) {
-	m_meta_data.shiftRight(offset, length, tracks);
+    if (track == tracks.first()) {
+	m_meta_data.shiftRight(offset, length);
     }
 
     emit sigSamplesInserted(track, offset, length);
@@ -1040,8 +1015,8 @@ void Kwave::SignalManager::slotSamplesDeleted(unsigned int track,
 
     // only adjust the meta data once per operation
     QList<unsigned int> tracks = selectedTracks();
-    if (track == tracks[0]) {
-	m_meta_data.shiftLeft(offset, length, tracks);
+    if (track == tracks.first()) {
+	m_meta_data.shiftLeft(offset, length);
     }
 
     emit sigSamplesDeleted(track, offset, length);
@@ -1069,12 +1044,12 @@ bool Kwave::SignalManager::deleteRange(sample_index_t offset,
     // put the selected meta data into a undo action
     if (m_undo_enabled) {
 	if (!registerUndoAction(new(std::nothrow) UndoDeleteMetaDataAction(
-	    m_meta_data.copy(offset, length, track_list))))
+	    m_meta_data.copy(offset, length))))
 	{
 	    abortUndoTransaction();
 	    return false;
 	}
-	m_meta_data.deleteRange(offset, length, track_list);
+	m_meta_data.deleteRange(offset, length);
 
 	// store undo data for all audio data (without meta data)
 	if (!registerUndoAction(new(std::nothrow) UndoDeleteAction(
@@ -1085,7 +1060,7 @@ bool Kwave::SignalManager::deleteRange(sample_index_t offset,
 	}
     } else {
 	// delete without undo
-	m_meta_data.deleteRange(offset, length, track_list);
+	m_meta_data.deleteRange(offset, length);
     }
 
     // delete the ranges in all tracks
@@ -1118,14 +1093,13 @@ bool Kwave::SignalManager::insertSpace(sample_index_t offset,
     if (!count) return true; // nothing to do
 
     // first store undo data for all tracks
-    unsigned int track;
     if (m_undo_enabled) {
 	if (!registerUndoAction(new(std::nothrow) Kwave::UndoInsertAction(
 	    m_parent_widget, track_list, offset, length))) return false;
     }
 
     // then insert space into all tracks
-    foreach (track, track_list) {
+    foreach (unsigned int track, track_list) {
 	m_signal.insertSpace(track, offset, length);
     }
 
@@ -1991,7 +1965,7 @@ bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
 //***************************************************************************
 void Kwave::SignalManager::mergeMetaData(const Kwave::MetaDataList &meta_data)
 {
-    m_meta_data.merge(meta_data);
+    m_meta_data.add(meta_data);
     emit sigMetaDataChanged(m_meta_data);
 }
 
