@@ -17,9 +17,13 @@
 
 #include "config.h"
 
-#include <KLocalizedString>
+#include <new>
+
+#include <QPointer>
 #include <QStringList>
 
+#include <KLocalizedString>
+
 #include "libkwave/Connect.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackSource.h"
@@ -88,8 +92,8 @@ QStringList *Kwave::AmplifyFreePlugin::setup(QStringList &previous_params)
     interpreteParameters(previous_params);
 
     // create the setup dialog
-    Kwave::AmplifyFreeDialog *dialog =
-	new Kwave::AmplifyFreeDialog(parentWidget());
+    QPointer<Kwave::AmplifyFreeDialog> dialog =
+	new(std::nothrow) Kwave::AmplifyFreeDialog(parentWidget());
     Q_ASSERT(dialog);
     if (!dialog) return Q_NULLPTR;
 
@@ -100,9 +104,9 @@ QStringList *Kwave::AmplifyFreePlugin::setup(QStringList &previous_params)
 	dialog->setParams(curve_params);
     }
 
-    QStringList *list = new QStringList();
+    QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
-    if (list && dialog->exec()) {
+    if (list && dialog->exec() && dialog) {
 	// user has pressed "OK"
 	*list << _("amplify free");
 	QString cmd = dialog->getCommand();
@@ -159,8 +163,7 @@ void Kwave::AmplifyFreePlugin::run(QStringList params)
     if (!sink.tracks()) return;
 
     // connect them
-    bool ok = true;
-    if (ok) ok = Kwave::connect(
+    bool ok = Kwave::connect(
 	source, SIGNAL(output(Kwave::SampleArray)),
 	mul,    SLOT(input_a(Kwave::SampleArray)));
     if (ok) ok = Kwave::connect(
