@@ -19,9 +19,10 @@
 
 #include <errno.h>
 #include <math.h>
-#include <new>
 #include <stdlib.h>
 
+#include <new>
+
 #include <QApplication>
 #include <QCursor>
 #include <QDateTime>
@@ -133,13 +134,14 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
     }
 
     // create the setup dialog
-    m_dialog = new Kwave::RecordDialog(parentWidget(), previous_params,
-                                       &m_controller,  mode);
+    m_dialog = new(std::nothrow) Kwave::RecordDialog(
+	parentWidget(), previous_params, &m_controller, mode
+    );
     Q_ASSERT(m_dialog);
     if (!m_dialog) return Q_NULLPTR;
 
     // create the lowlevel recording thread
-    m_thread = new Kwave::RecordThread();
+    m_thread = new(std::nothrow) Kwave::RecordThread();
     Q_ASSERT(m_thread);
     if (!m_thread) {
 	delete m_dialog;
@@ -214,9 +216,9 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
     if (mode == Kwave::RecordDialog::START_RECORDING)
 	m_controller.actionStart();
 
-    QStringList *list = new QStringList();
+    QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
-    if (list && (m_dialog->exec() == QDialog::Accepted)) {
+    if (list && (m_dialog->exec() == QDialog::Accepted) && m_dialog) {
 	// user has pressed "OK"
 	*list = m_dialog->params().toList();
     } else {
@@ -298,28 +300,28 @@ void Kwave::RecordPlugin::setMethod(Kwave::record_method_t method)
 	    switch (method) {
 #ifdef HAVE_OSS_SUPPORT
 		case Kwave::RECORD_OSS:
-		    m_device = new Kwave::RecordOSS();
+		    m_device = new(std::nothrow) Kwave::RecordOSS();
 		    Q_ASSERT(m_device);
 		    break;
 #endif /* HAVE_OSS_SUPPORT */
 
 #ifdef HAVE_ALSA_SUPPORT
 		case Kwave::RECORD_ALSA:
-		    m_device = new Kwave::RecordALSA();
+		    m_device = new(std::nothrow) Kwave::RecordALSA();
 		    Q_ASSERT(m_device);
 		    break;
 #endif /* HAVE_ALSA_SUPPORT */
 
 #ifdef HAVE_PULSEAUDIO_SUPPORT
 		case Kwave::RECORD_PULSEAUDIO:
-		    m_device = new Kwave::RecordPulseAudio();
+		    m_device = new(std::nothrow) Kwave::RecordPulseAudio();
 		    Q_ASSERT(m_device);
 		    break;
 #endif /* HAVE_PULSEAUDIO_SUPPORT */
 
 #ifdef HAVE_QT_AUDIO_SUPPORT
 		case Kwave::RECORD_QT:
-		    m_device = new Kwave::RecordQt();
+		    m_device = new(std::nothrow) Kwave::RecordQt();
 		    Q_ASSERT(m_device);
 		    break;
 #endif /* HAVE_QT_AUDIO_SUPPORT */
@@ -938,7 +940,7 @@ void Kwave::RecordPlugin::setupRecordThread()
 		case Kwave::SampleFormat::Unsigned: /* FALLTHROUGH */
 		case Kwave::SampleFormat::Signed:
 		    // decoder for all linear formats
-		    m_decoder = new Kwave::SampleDecoderLinear(
+		    m_decoder = new(std::nothrow) Kwave::SampleDecoderLinear(
 			m_device->sampleFormat(),
 			m_device->bitsPerSample(),
 			m_device->endianness()
@@ -1428,7 +1430,7 @@ void Kwave::RecordPlugin::flushPrerecordingQueue()
     Q_ASSERT(m_writers);
     if (!m_writers) return;
     Q_ASSERT(tracks == m_writers->tracks());
-    if (!tracks || (tracks != m_writers->tracks())) return;
+    if (tracks != m_writers->tracks()) return;
 
     for (unsigned int track=0; track < tracks; ++track) {
 	Kwave::SampleFIFO &fifo = m_prerecording_queue[track];
@@ -1543,7 +1545,7 @@ void Kwave::RecordPlugin::processBuffer()
 
     // use a copy of the state, in case it changes below ;-)
     Kwave::RecordState state = m_state;
-    for (unsigned int track=0; track < tracks; ++track) {
+    for (unsigned int track = 0; track < tracks; ++track) {
 	// decode and care for all special effects, meters and so on
 	// split off and decode buffer with current track
 	split(buffer, buf, bytes_per_sample, track, tracks);
@@ -1607,7 +1609,7 @@ void Kwave::RecordPlugin::processBuffer()
 //***************************************************************************
 void Kwave::RecordPlugin::prerecordingChanged(bool enable)
 {
-    (void)enable;
+    Q_UNUSED(enable);
     InhibitRecordGuard _lock(*this); // activate the change
 }
 
